pub struct PaginatedQueryArgs<T>where
T: Debug,{
pub first: usize,
pub after: Option<T>,
}Expand description
A cursor-based pagination structure for efficiently paginating through large datasets
The PaginatedQueryArgs<T> encapsulates a first field that specifies the count of entities to fetch per query, and an optional after field
that specifies the cursor to start from for the current query. The <T> parameter represents cursor type, which depends on the sorting field.
A field’s cursor is generated by EsRepo if it has list_by option.
Examples
ⓘ
// Initial query - fetch first 10 users after an existing user id
let query_args = PaginatedQueryArgs {
first: 10,
after: Some(user_cursor::UserByIdCursor {
id: some_existing_user_id // assume this variable exists
}),
};
// Execute query using `query_args` argument of `PaginatedQueryArgs` type
let result = users.list_by_id(query_args, ListDirection::Ascending).await?;
// Continue pagination using the updated `next_query_args` of `PaginatedQueryArgs` type
if result.has_next_page {
let next_query_args = PaginatedQueryArgs {
first: 10,
after: result.end_cursor, // Use cursor from previous result to update `after`
};
let next_result = users.list_by_id(next_query_args, ListDirection::Ascending).await?;
}Fields
first: usizeSpecifies the number of entities to fetch per query
after: Option<T>Specifies the cursor/marker to start from for current query